@@ -31,7 +31,7 @@ class CreateProbeTasksRequest(AbstractModel):
         :type TaskType: int
         :param _Nodes: 拨测节点，如10001，具体拨测地域运营商对应的拨测点编号可联系云拨测确认。
         :type Nodes: list of str
-        :param _Interval: 拨测间隔
+        :param _Interval: 拨测间隔，单位为分钟
         :type Interval: int
         :param _Parameters: 拨测参数，详细可参考云拨测官方文档,链接:https://cloud.tencent.com/document/product/248/87308#createprobetasks。
         :type Parameters: str
@@ -103,7 +103,7 @@ class CreateProbeTasksRequest(AbstractModel):
 
     @property
     def Interval(self):
-        """拨测间隔
+        """拨测间隔，单位为分钟
         :rtype: int
         """
         return self._Interval
@@ -2426,7 +2426,7 @@ class ProbeTask(AbstractModel):
         :param _NodeIpType: 拨测任务所选的拨测点IP类型，0-不限，1-IPv4，2-IPv6
 注意：此字段可能返回 null，表示取不到有效值。
         :type NodeIpType: int
-        :param _Interval: 拨测间隔
+        :param _Interval: 拨测间隔，单位为分钟
         :type Interval: int
         :param _Parameters: 拨测参数
         :type Parameters: str
@@ -2558,7 +2558,7 @@ class ProbeTask(AbstractModel):
 
     @property
     def Interval(self):
-        """拨测间隔
+        """拨测间隔，单位为分钟
         :rtype: int
         """
         return self._Interval
@@ -3394,6 +3394,8 @@ class UpdateProbeTaskConfigurationListRequest(AbstractModel):
         :type ResourceIDs: list of str
         :param _NodeIpType: 拨测节点的IP类型，0-不限，1-IPv4，2-IPv6
         :type NodeIpType: int
+        :param _BatchTasks: 批量任务名-地址
+        :type BatchTasks: list of ProbeTaskBasicConfiguration
         """
         self._TaskIds = None
         self._Nodes = None
@@ -3402,6 +3404,7 @@ class UpdateProbeTaskConfigurationListRequest(AbstractModel):
         self._Cron = None
         self._ResourceIDs = None
         self._NodeIpType = None
+        self._BatchTasks = None
 
     @property
     def TaskIds(self):
@@ -3481,6 +3484,17 @@ class UpdateProbeTaskConfigurationListRequest(AbstractModel):
     def NodeIpType(self, NodeIpType):
         self._NodeIpType = NodeIpType
 
+    @property
+    def BatchTasks(self):
+        """批量任务名-地址
+        :rtype: list of ProbeTaskBasicConfiguration
+        """
+        return self._BatchTasks
+
+    @BatchTasks.setter
+    def BatchTasks(self, BatchTasks):
+        self._BatchTasks = BatchTasks
+
 
     def _deserialize(self, params):
         self._TaskIds = params.get("TaskIds")
@@ -3490,6 +3504,12 @@ class UpdateProbeTaskConfigurationListRequest(AbstractModel):
         self._Cron = params.get("Cron")
         self._ResourceIDs = params.get("ResourceIDs")
         self._NodeIpType = params.get("NodeIpType")
+        if params.get("BatchTasks") is not None:
+            self._BatchTasks = []
+            for item in params.get("BatchTasks"):
+                obj = ProbeTaskBasicConfiguration()
+                obj._deserialize(item)
+                self._BatchTasks.append(obj)
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
